"use client";

import React, { useEffect, useState, Suspense } from 'react';
import { useSearchParams } from 'next/navigation';
import NetworkPage from '@/app/components/NetworkPage'; // Ensure this path is correct
import Head from 'next/head'; 
import AdSense from '@/app/components/AdSense';

// Define a type for the network data
interface NetworkData {
  results: any[];
  name: string; // Add this line
  logo_path?: string; // Add this line
  // Add other properties as needed
}

const NetworkDetailContent: React.FC = () => {
  const searchParams = useSearchParams();
  const networkId = searchParams.get('id'); // Get the networkId from the query parameter

  const [networkIdNumber, setNetworkIdNumber] = useState<number | null>(null);
  const [networkData, setNetworkData] = useState<NetworkData | null>(null); // State to store network data
  const [page, setPage] = useState(1); // State to track the current page
  const [loading, setLoading] = useState(false); // State to track loading status

  useEffect(() => {
    if (networkId) {
      const parsedId = parseInt(networkId, 10);
      setNetworkIdNumber(parsedId);

      // Fetch network details for SEO purposes
      const fetchNetworkData = async () => {
        try {
          setLoading(true);
          const response = await fetch(`https://api.themoviedb.org/3/network/${parsedId}?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&page=${page}`);
          const data = await response.json();
          setNetworkData((prevData: NetworkData | null) => ({
            ...data,
            results: [...(prevData?.results || []), ...(data.results || [])]
          }));
        } catch (error) {
          console.error("Error fetching network data:", error);
        } finally {
          setLoading(false);
        }
      };

      fetchNetworkData();
    }
  }, [networkId, page]);

  const handleLoadMore = () => {
    setPage(prevPage => prevPage + 1);
  };

  if (!networkIdNumber || !networkData) {
    return <div>Loading...</div>;
  }

  return (
    <>
      <Head>
        <title>{`${networkData.name} - TV Shows & Movies - Delgor`}</title>
        <meta name="description" content={`Discover TV shows and movies from ${networkData.name} on Delgor. Stream your favorite content from ${networkData.name}.`} />
        <link rel="canonical" href={`https://www.delgor.com/network?id=${networkId}`} />
        <meta property="og:title" content={`${networkData.name} - TV Shows & Movies - Delgor`} />
        <meta property="og:description" content={`Stream TV shows and movies from ${networkData.name} on Delgor. Enjoy the best content available.`} />
        <meta property="og:type" content="website" />
        <meta property="og:url" content={`https://www.delgor.com/network?id=${networkId}`} />
        <meta property="og:image" content={networkData.logo_path ? `https://image.tmdb.org/t/p/w500${networkData.logo_path}` : '/images/fallback-image.jpg'} />
        <meta property="og:image:alt" content={`${networkData.name} Logo`} />
        <meta property="og:site_name" content="Delgor" />
        {/* Structured Data for the Network */}
        <script type="application/ld+json">
          {JSON.stringify({
            "@context": "https://schema.org",
            "@type": "Organization",
            "name": networkData.name,
            "url": `https://www.delgor.com/network?id=${networkId}`,
            "logo": networkData.logo_path ? `https://image.tmdb.org/t/p/w500${networkData.logo_path}` : '/images/fallback-image.jpg',
            "sameAs": [
              `https://www.themoviedb.org/network/${networkId}`,
              // Add other social media or relevant URLs if available
            ]
          })}
        </script>
      </Head>
      <NetworkPage networkId={networkIdNumber} />
      <div className="w-full my-4">
        <AdSense />
      </div>

    </>
  );
};

const NetworkDetail: React.FC = () => {
  return (
    <Suspense fallback={<div>Loading...</div>}>
      <NetworkDetailContent />
    </Suspense>
  );
};

export default NetworkDetail;
